@@ -4,10 +4,15 @@ from .. import extra
 
 
 @extra
-def add_vertical_space(num_lines: int = 1):
-    """Add vertical space to your Streamlit app."""
+def add_vertical_space(num_lines: int = 1) -> None:
+    """
+    Add vertical space to your Streamlit app.
+
+    Args:
+        num_lines (int, optional): Height of the vertical space (given in number of lines). Defaults to 1.
+    """
     for _ in range(num_lines):
-        st.write("")
+        st.write("")  # This is just a way to do a line break!
 
 
 def example():
@@ -21,4 +26,4 @@ __desc__ = "Add n lines of vertical space to your Streamlit app in one command"
 __icon__ = "👽"  # give your extra an icon!
 __examples__ = [example]  # create some examples to show how cool your extra is!
 __author__ = "Tyler Richards"
-__experimental_playground__ = False  # Optional
+__playground__ = True
