@@ -22,6 +22,9 @@ div[class*="StatusWidget"]{
 
 @extra
 def center_running():
+    """
+    Have the "running man" animation in the center of the screen instead of the top right corner.
+    """
     st.markdown(center_css, unsafe_allow_html=True)
 
 
@@ -40,4 +43,4 @@ __author__ = "koninhoo"
 __forum_url__ = (
     "https://discuss.streamlit.io/t/change-the-running-widget-position/30466"
 )
-__experimental_playground__ = False
+__playground__ = False
