@@ -23,4 +23,4 @@ __author__ = "Arnaud Miribel"
 __github_repo__ = "arnaudmiribel/streamlit-faker"
 __pypi_name__ = "streamlit-faker"
 __package_name__ = "streamlit_faker"
-__experimental_playground__ = False
+__playground__ = False
