@@ -49,9 +49,9 @@ def example_collapsible_content():
 
 __func__ = mdlit
 __title__ = "Markdownlit"
-__desc__ = (
-    """markdownlit adds a set of lit Markdown commands for your Streamlit apps!"""
-)
+__desc__ = """markdownlit adds a set of lit Markdown commands for your Streamlit apps!
+    **Note you can now use colored text in markdown with native Streamlit, check
+    out [the docs](https://docs.streamlit.io/library/api-reference/text/st.markdown)!**"""
 __icon__ = "〽️"
 __examples__ = [
     example_link_and_colors,
@@ -61,4 +61,4 @@ __author__ = "Arnaud Miribel"
 __github_repo__ = "arnaudmiribel/markdownlit"
 __pypi_name__ = "markdownlit"
 __package_name__ = "markdownlit"
-__experimental_playground__ = True
+__playground__ = True
