@@ -28,7 +28,7 @@ def _transform_arguments(*args, **kwargs) -> tuple[str, Iterable[Any], dict[str,
             options = options.iloc[:, 0]
             options = list(pd.concat([pd.Series([no_selection_label]), options]))
         else:
-            options = [no_selection_label] + list(options)
+            options = [no_selection_label, *list(options)]
         kwargs["options"] = options
 
     return no_selection_label, _args, kwargs
@@ -36,16 +36,13 @@ def _transform_arguments(*args, **kwargs) -> tuple[str, Iterable[Any], dict[str,
 
 @extra
 def selectbox(*args, **kwargs):
-    """A selectbox that returns None unless the user has explicitly selected one of the
-    options.
-
-    All arguments are passed to st.selectbox except for `no_selection_label`, which is
+    """
+    A selectbox that returns None unless the user has explicitly selected one of the
+    options. All arguments are passed to st.selectbox except for `no_selection_label`, which is
     used to specify the label of the option that represents no selection.
 
-    Parameters
-    ----------
-    no_selection_label : str
-        The label to use for the no-selection option. Defaults to "---".
+    Args:
+        no_selection_label (str): The label to use for the no-selection option. Defaults to "---".
     """
     no_selection_label, _args, _kwargs = _transform_arguments(*args, **kwargs)
 
@@ -63,6 +60,10 @@ def example():
 
         The selectbox below has no default value, so it will return None until the
         user selects an option.
+
+        **Note**: Since streamlit 1.27.0, you can initialize widgets with an empty
+        state by setting None as an initial value for st.number_input, st.selectbox,
+        st.date_input, st.time_input, st.radio, st.text_input, and st.text_area!
         """
     )
     result = selectbox("Select an option", ["A", "B", "C"])
@@ -79,10 +80,12 @@ def example():
 __title__ = "No-Default Selectbox"
 __desc__ = """
 Just like st.selectbox, but with no default value -- returns None if nothing is selected.
-
 Meant to be a solution to https://github.com/streamlit/streamlit/issues/949
+
+**Note**: Since streamlit 1.27.0, you can initialize widgets with an empty state by setting None as an initial value for st.number_input, st.selectbox, st.date_input, st.time_input, st.radio, st.text_input, and st.text_area!
 """
 __icon__ = "🗳️"
 __examples__ = [example]
 __author__ = "Zachary Blackwood"
-__experimental_playground__ = False
+__playground__ = True
+__deprecated__ = True
