@@ -1,19 +1,24 @@
+from __future__ import annotations
+
 import streamlit as st
 
 from .. import extra
 
 
+def toggle_state(key: str):
+    if key not in st.session_state:
+        st.session_state[key] = False
+
+    st.session_state[key] = not st.session_state[key]
+
+
 @extra
-def button(*args, key=None, **kwargs):
+def button(*args, key: str | None = None, **kwargs) -> bool:
     """
     Works just like a normal streamlit button, but it remembers its state, so that
     it works as a toggle button. If you click it, it will be pressed, and if you click
-    it again, it will be unpressed.
-
-    args:
-        Same as st.button
-    kwargs:
-        Same as st.button except key is required
+    it again, it will be unpressed. Args and output are the same as for
+    [st.button](https://docs.streamlit.io/library/api-reference/widgets/st.button)
     """
 
     if key is None:
@@ -25,18 +30,26 @@ def button(*args, key=None, **kwargs):
     if "type" not in kwargs:
         kwargs["type"] = "primary" if st.session_state[key] else "secondary"
 
-    if st.button(*args, **kwargs):
-        st.session_state[key] = not st.session_state[key]
-        st.experimental_rerun()
+    derived_key = f"{key}_derived"
+
+    original_on_click = kwargs.get("on_click")
+
+    def callback():
+        if original_on_click is not None:
+            original_on_click()
+        toggle_state(key)
+
+    kwargs["on_click"] = callback
+
+    st.button(*args, key=derived_key, **kwargs)
 
     return st.session_state[key]
 
 
 def example():
-    if button("Button 1", key="button1"):
-        if button("Button 2", key="button2"):
-            if button("Button 3", key="button3"):
-                st.write("All 3 buttons are pressed")
+    if button("Button 1", key="button1") and button("Button 2", key="button2"):
+        if button("Button 3", key="button3"):
+            st.write("All 3 buttons are pressed")
 
 
 __title__ = "Stateful Button"
@@ -45,4 +58,4 @@ __icon__ = "🔛"
 __examples__ = [example]
 __author__ = "Zachary Blackwood"
 __forum_url__ = "https://discuss.streamlit.io/t/how-to-use-multiple-buttons-in-st-columns/35088/4?u=blackary"
-__experimental_playground__ = False
+__playground__ = True
