@@ -8,21 +8,22 @@ def to_do(st_commands, checkbox_id):
     """Create a to_do item
 
     Args:
-        st_commands (_type_): _description_
-        checkbox_id (_type_): _description_
+        st_commands (_type_): List of (cmd, args) where cmd is a
+            streamlit command and args are the arguments of the command
+        checkbox_id (str): Use as a key to the checkbox
 
     Returns:
-        _type_: _description_
+        None: Prints the to do list
     """
     cols = st.columns((1, 20))
     done = cols[0].checkbox(" ", key=checkbox_id)
     if done:
-        for (cmd, *args) in st_commands:
+        for cmd, *args in st_commands:
             with cols[1]:
                 if cmd == st.write:
                     text = args[0]
                     cols[1].write(
-                        "<s style='color: rgba(49, 51, 63, 0.4)'>" f" {text} </s>",
+                        f"<s style='color: rgba(49, 51, 63, 0.4)'> {text} </s>",
                         unsafe_allow_html=True,
                     )
                 else:
@@ -45,12 +46,11 @@ def to_do(st_commands, checkbox_id):
                         cmd(*args)
 
     else:
-        for (cmd, *args) in st_commands:
+        for cmd, *args in st_commands:
             with cols[1]:
                 if cmd == st.write:
                     st.write(*args, unsafe_allow_html=True)
                 else:
-
                     cmd(*args)
     st.write("")
     return done
@@ -78,3 +78,4 @@ __examples__ = [example]
 __author__ = "Arnaud Miribel"
 __github_repo__ = "arnaudmiribel/stodo"
 __streamlit_cloud_url__ = "http://stodoo.streamlitapp.com"
+__playground__ = True
