@@ -5,7 +5,19 @@ from .. import extra
 
 @extra
 def switch_page(page_name: str):
-    from streamlit.runtime.scriptrunner import RerunData, RerunException
+    """
+    Switch page programmatically in a multipage app
+
+    Args:
+        page_name (str): Target page name
+    """
+
+    try:
+        from streamlit.runtime.scriptrunner import RerunData, RerunException
+    except ModuleNotFoundError:  # For streamlit > 1.37
+        from streamlit.runtime.scriptrunner_utils.exceptions import RerunException
+        from streamlit.runtime.scriptrunner_utils.script_requests import RerunData
+
     from streamlit.source_util import get_pages
 
     def standardize_name(name: str) -> str:
@@ -37,7 +49,11 @@ def example():
 
 def test_switch_page():
     import pytest
-    from streamlit.runtime.scriptrunner import RerunException
+
+    try:
+        from streamlit.runtime.scriptrunner import RerunException
+    except ModuleNotFoundError:
+        from streamlit.runtime.scriptrunner_utils.exceptions import RerunException
 
     with pytest.raises(RerunException):
         switch_page("streamlit app")
@@ -51,8 +67,10 @@ def test_switch_invalid_page():
 
 
 __title__ = "Switch page function"
-__desc__ = "Function to switch page programmatically in a MPA"
+__desc__ = """Function to switch page programmatically in a MPA.
+**Note:** [st.switch_page](https://docs.streamlit.io/develop/api-reference/navigation/st.switch_page) has been released in Streamlit 1.37.0!"""
 __icon__ = "🖱️"
 __examples__ = [example]
 __author__ = "Zachary Blackwood"
 __tests__ = [test_switch_page, test_switch_invalid_page]
+__deprecated__ = True
